-- initialize mission parameters

numberOfFighterJets = {blue = 3, red = 3}

-- functions used by the mission

updating = function(playerGroupName) -- this function gets executed whenever the "request assignment" menu item has been selected
local groupName,value,counter

	local coa = HS.getGroupCoalition(playerGroupName)
	for groupName,value in pairs(HS_groupsInNeed[coa]) do
		local group = Group.getByName(groupName)
		if group then
			local roundsLeft = 0
			local units = Group.getUnits(group)
			for counter = 1,#units do
				if units[counter] then
					roundsLeft = roundsLeft + Unit.getAmmo(units[counter])[1].count
				end
			end
			if HS.estimatePresentPosition(groupName) and Group.getSize(group)>0 and roundsLeft > 0 and HS.assignADF(coa,groupName) then
				HS.out(coa,groupName .. ' located at ' .. HS.estimatePresentPosition(groupName) .. ' with ' .. Group.getSize(group) .. ' men and ' .. roundsLeft .. ' rounds of ammo left., broadcasting on ' .. HS.assignADF(coa,groupName),20)
			end
		end
	end
end

toDoListRequested = function(playerGroupName) -- this function gets executed whenever the "request assignment" menu item has been selected
	local coa = HS.getGroupCoalition(playerGroupName)
	HS.out(coa,'This is ' .. playerGroupName .. '. Ready for task assignment. All units in distress, report in. Over.',10)
	mist.scheduleFunction(updating,{playerGroupName},timer.getTime()+10)
end

assignmentRequested = function(playerGroupName) -- this function gets executed whenever the "request assignment" menu item has been selected
	local coa = HS.getGroupCoalition(playerGroupName)
	local lat, lon = coord.LOtoLL(mist.utils.zoneToVec3('Drop Off Zone #' .. cargoCount))
	local outText = mist.tostringLL(lat, lon, 0, true)
	HS.out(coa,'This is ' .. playerGroupName .. '. What is my present assignment? Over.',10)
	local ADF = HS.assignADF(coa,'Drop Off Guy Group #' .. cargoCount)
	mist.scheduleFunction(HS.out,{coa,playerGroupName .. '. Drop your cargo at ' .. outText .. ', use ' .. ADF .. ' to locate drop zone.' ,10},timer.getTime()+10)
end

troopCountRequested = function(playerGroupName) -- this function gets executed whenever the "troops on board" menu item has been selected
local count

	local coa = HS.getGroupCoalition(playerGroupName)
	local group = Group.getByName(playerGroupName)
	local units = Group.getUnits(group)
	for count = 1,#units do
		local playerName = Unit.getName(units[count])
		HS.out(coa,'This is ' .. playerName .. '. There are ' .. HS.getNumberOfTroopsInCabin(playerName) .. ' infantry troops on board',10)
		HS.out(coa,'This is ' .. playerName .. '. There are ' .. HS.getNumberOfRescuedPilotsInCabin(playerName) .. ' rescued pilots on board',10)
	end
end

presentPositionRequested = function(playerGroupName) -- this function gets executed whenever the "copilot estimate position" menu item has been selected
	local playerName = Unit.getName(Group.getUnits(Group.getByName(playerGroupName))[1])
	HS.outUnit(playerName,'[copilot for ' .. playerName .. '] I estimate our present position to be at ' .. HS.estimatePresentPosition(playerGroupName),30)
end

flareRequested = function(playerGroupName) -- this function gets executed whenever the "flares requested" menu item has been selected
	local color = {'green','red','white','yellow'}
	local playerName = Unit.getName(Group.getUnits(Group.getByName(playerGroupName))[1])
	local coa = HS_getGroupCoalition(playerGroupName)
	local colorSelected = mist.random(#color)
	HS.out(coa,'This is ' .. playerName .. '. All friendly infantry groups within 5 km from ' .. HS.estimatePresentPosition(playerGroupName) .. ', mark your positions with a ' .. color[colorSelected] .. ' flare.',10)
	HS.friendlyInfantryReleaseFlare(coa,playerGroupName,colorSelected-1)
end

playerHasBecomeActive = function(playerName) -- this function gets executed whenever a player becomes active
	local playerUnit = Unit.getByName(playerName)
	if playerUnit then
		local coa = HS.getUnitCoalition(playerName)
		local playerGroupName = Group.getName(Unit.getGroup(playerUnit))
		if playerUnit:getTypeName() == 'UH-1H' or playerUnit:getTypeName() == 'Mi-8MT' then -- radio items specific for transport choppers
			HS.outUnit(playerName,playerName .. ', provide CSAR. Use F10 to load/unload pilots down.',30)
			HS.addRadioItem(playerGroupName,'copilot, estimate present position',presentPositionRequested,{playerGroupName}) -- add radio item
			HS.addRadioItem(playerGroupName,'request assignment',toDoListRequested,{playerGroupName}) -- add radio item
			HS.addRadioItem(playerGroupName,'load troops',HS.groupLoadTroops,{playerGroupName}) -- add radio item
			HS.addRadioItem(playerGroupName,'offload troops',HS.groupOffloadTroops,{playerGroupName}) -- add radio item
			HS.addRadioItem(playerGroupName,'number of troops on board',troopCountRequested,{playerGroupName}) -- add radio item
			HS.addCheckForSinkRate(playerName) -- make sure that copilot gives warning when dangerously close to VRS
			HS.addCheckForFlare(playerGroupName) -- make sure friendly infantry will release flare once they spot this unit
			HS.addRadioItem(playerGroupName,'friendlies, release flare',flareRequested,{playerGroupName}) -- add radio item
			HS.onTakeOffDo(playerName,HS.out,{coa,playerName .. ' has taken off',10}) -- give message when unit takes off
			HS.onTouchDownDo(playerName,HS.out,{coa,playerName .. ' has landed',10}) -- give message when unit touches down
		end
		if playerUnit:getTypeName() == 'F-86F Sabre' or playerUnit:getTypeName() == 'MiG-15bis' then -- radio items specific for transport choppers
			HS.outUnit(playerName,playerName .. ', take off and engage bandits.',30)
			HS.addBogeyDope(playerName)
		end
	end
end

playerHasBecomeInactive = function(playerName) -- this function gets executed whenever a player becomes inactive
	local coa = HS.getUnitCoalition(playerName)
	HS.out(coa,playerName .. ' has become inactive.',10)
	HS.removeRadioItems(playerName) -- remove all radio items for this player
end

-- end of functions

-- define sound files

HS.setRadioStaticAudio('RadioClickAfter.wav')
HS.setBeaconAudio('VHF_WarningTone.wav')
HS.setSinkRateAudio('sinkRate.wav')

-- end define sound files

-- define what happens when units become active

cargoCount = 1

for count = 1, #mist.DBs.MEunitsByCat.helicopter do
	HS.onBecomesActiveDo(mist.DBs.MEunitsByCat.helicopter[count].unitName,playerHasBecomeActive,{mist.DBs.MEunitsByCat.helicopter[count].unitName})
	HS.onBecomesInactiveDo(mist.DBs.MEunitsByCat.helicopter[count].unitName,playerHasBecomeInactive,{mist.DBs.MEunitsByCat.helicopter[count].unitName})
end

for count = 1, #mist.DBs.MEunitsByCat.plane do
	HS.onBecomesActiveDo(mist.DBs.MEunitsByCat.plane[count].unitName,playerHasBecomeActive,{mist.DBs.MEunitsByCat.plane[count].unitName})
	HS.onBecomesInactiveDo(mist.DBs.MEunitsByCat.plane[count].unitName,playerHasBecomeInactive,{mist.DBs.MEunitsByCat.plane[count].unitName})
end

-- end define what happens when units become active

-- initialize AI air superiority fighters

HS.setAirBattleZone('Air Battle Zone')

for count = 1,numberOfFighterJets.blue do
	HS.flyFighterMission('blue','Sabre AI Group #' .. count)
end

for count = 1,numberOfFighterJets.red do
	HS.flyFighterMission('red','Mig-15 AI Group #' .. count)
end

-- end initialize AI air superiority fighters

-- schedule mission restart in MP missions

HS.scheduleMissionRestart(10800,900)
